import typer
import json
import subprocess

app = typer.Typer()


@app.command()
def build(path):
    with open(f"{path}/manifest.json", 'r') as file:
        manifest = json.load(file)
        namespace = manifest["namespace"]
        name = manifest["name"]
        version = manifest["version"]
        subprocess.run(
            f"docker build -t {namespace}/{name}:{version} {path}".split(" ")
        )


@app.command()
def help():
    typer.echo("build and push funcker function")



import docker
import json
import os


class Funcker:
    def __init__(self, namespace, name, version="latest"):
        self.namespace = namespace
        self.name = name
        self.version = version
        self.image = f"{namespace}/{name}:{version}"

    def run(self, *args):
        client = docker.from_env()
        serialized_args = [json.dumps(arg) for arg in args]
        res = client.containers.run(
            name=self.name,
            image=self.image,
            command=serialized_args,
            remove=True,
            volumes={os.getcwd(): {
                'bind': f"/tmp/{self.name}", 'mode': 'rw'}
            }
        ).decode()

        return json.loads(res)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['funcker', 'funcker.cli', 'funcker.plug', 'funcker.run']

package_data = \
{'': ['*']}

install_requires = \
['docker>=5.0.3,<6.0.0', 'typer[all]>=0.4.2,<0.5.0']

entry_points = \
{'console_scripts': ['funcker = funcker.cli.main:app']}

setup_kwargs = {
    'name': 'funcker',
    'version': '0.1.1',
    'description': 'plug and run funcker function',
    'long_description': '# Funcker\n\n> plug and run funcker function\n',
    'author': 'romainprignon',
    'author_email': 'pro.rprignon@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
